@@ -66,11 +66,11 @@ When called from Lisp code, sends CMD directly without prompting."
      :cli     "claude")
     (gemini
      :label "Gemini CLI"
-     :require gemini-cli
-     :start   gemini-cli
-     :switch  gemini-cli-switch-to-buffer
-     :send    gemini-cli--do-send-command
-     :resume  gemini-cli-resume
+     :require ai-code-gemini-cli
+     :start   ai-code-gemini-cli
+     :switch  ai-code-gemini-cli-switch-to-buffer
+     :send    ai-code-gemini-cli-send-command
+     :resume  ai-code-gemini-cli-resume
      :config  "~/.gemini/settings.json"
      :upgrade "npm install -g @google/gemini-cli"
      :cli     "gemini")
@@ -113,7 +113,17 @@ When called from Lisp code, sends CMD directly without prompting."
      :resume  ai-code-grok-cli-resume
      :config  "~/.config/grok/config.json"
      :upgrade "bun add -g @vibe-kit/grok-cli"
-     :cli     "grok"))
+     :cli     "grok")
+    (cursor
+     :label "Cursor CLI"
+     :require ai-code-cursor-cli
+     :start   ai-code-cursor-cli
+     :switch  ai-code-cursor-cli-switch-to-buffer
+     :send    ai-code-cursor-cli-send-command
+     :resume  ai-code-cursor-cli-resume
+     :config  "~/.cursor"
+     :upgrade "cursor-agent update"
+     :cli     "cursor-agent"))
   "Available AI backends and how to integrate with them.
 Each entry is (KEY :label STRING :require FEATURE :start FN :switch FN
 :send FN :resume FN-or-nil :upgrade STRING-or-nil :cli STRING).
