@@ -19,7 +19,7 @@
 
 (declare-function ai-code-read-string "ai-code-input")
 (declare-function ai-code--insert-prompt "ai-code-prompt-mode")
-(declare-function ai-code--get-clipboard-text "ai-code")
+(declare-function ai-code--get-clipboard-text "ai-code-interface")
 (declare-function ai-code--get-git-relative-paths "ai-code-discussion")
 (declare-function ai-code--get-region-location-info "ai-code-discussion")
 (declare-function ai-code--format-repo-context-info "ai-code-file")
@@ -244,6 +244,10 @@ line, with proper indentation.  If cursor is inside a function, implement
 comments for that function.
 Otherwise implement comments for the entire current file.
 Argument ARG is the prefix argument."
+  ;; DONE: if the current line under cursor is a comment prefix with DONE: ,
+  ;; ask the user if they want to toggle it to TODO, or delete the comment line
+  ;; DONE: this function is too long. break it into three major branch
+  ;; with sub functions
   (interactive "P")
   (if (not buffer-file-name)
       (user-error "Error: buffer-file-name must be available")
